## empty

`empty()`

Returns an empty Enumerable

**Parameters**


**Returns**

An `Enumerable` object that contains no elements

**Example**

<pre><code>
from py_linq import Enumerable

test = Enumerable([1, 2, 3]).empty()
print test
# []
</code></pre>